@@ -1,7 +1,9 @@
 import json
-import os
+import pathlib
+from typing import IO, Optional
 
 import click
+import click_aliases
 import pygments.lexers
 import pygments.util
 import pyperclip
@@ -10,23 +12,24 @@ import requests
 from dpaster import __version__
 
 
-CONF_PATH = os.path.join(os.path.expanduser("~/.config"), "dpaster", "dpaster.conf")
+CONF_PATH = pathlib.Path("~/.config").expanduser() / "dpaster" / "dpaster.conf"
 
 
-@click.group()
+@click.group(cls=click_aliases.ClickAliasedGroup)
 @click.pass_context
 @click.version_option(__version__)
-def cli(ctx): # pylint: disable=unused-argument
+def cli(ctx: click.Context) -> None: # pylint: disable=unused-argument
     """
     Client interface for https://dpaste.com/ pastebin
     """
 
-@cli.command()
+@cli.command(aliases=['p'])
 @click.option(
     "--syntax", "-s",
     help="Choose syntax (e.g. python, java, bash)",
     required=False,
-    metavar="OPT"
+    metavar="OPT",
+    type=str
 )
 @click.option(
     "--expires", "-e",
@@ -49,16 +52,23 @@ def cli(ctx): # pylint: disable=unused-argument
     required=False,
     metavar="OPT"
 )
+@click.option(
+    "--copy", "-c",
+    is_flag=True,
+    help="Copy URL to clipboard",
+    required=False,
+    metavar="OPT"
+)
 @click.argument('file', type=click.File("r"), default="-", required=False)
-def paste(file, syntax, expires, title, raw):
+def paste(file: IO, syntax: str, expires: int, title: str, raw: bool, copy: bool) -> None:
     """
-    Paste to dpaste.org
+    Paste to dpaste.com
     """
     try:
         with open(CONF_PATH, "r") as conf_file:
             options = json.load(conf_file)
     except FileNotFoundError:
-        os.makedirs(os.path.dirname(CONF_PATH), exist_ok=True)
+        pathlib.Path.mkdir(CONF_PATH.parent, exist_ok=True)
         with open(CONF_PATH, "w") as conf_file:
             options = {
                 "enable_autocp": False,
@@ -82,17 +92,18 @@ def paste(file, syntax, expires, title, raw):
 
     req.raise_for_status()
 
-    url = req.text.strip()
+    url: str = req.text.strip()
 
     if raw or options.get("enable_raw"):
         url += ".txt"
 
     click.echo(url)
 
-    if options["enable_autocp"]:
+    if copy or options["enable_autocp"]:
         pyperclip.copy(url)
 
-@cli.command()
+
+@cli.command(aliases=['c'])
 @click.option(
     "--show",
     is_flag=True,
@@ -120,7 +131,13 @@ def paste(file, syntax, expires, title, raw):
     metavar="OPT",
     type=int
 )
-def config(show, enable_autocp, enable_raw, default_syntax, default_expires):
+def config(
+    show: bool,
+    enable_autocp: Optional[bool],
+    enable_raw: Optional[bool],
+    default_syntax: Optional[str],
+    default_expires: Optional[int]
+) -> None:
     """
     Configure available settings
     """
@@ -129,11 +146,11 @@ def config(show, enable_autocp, enable_raw, default_syntax, default_expires):
             options = json.load(conf_file)
             for key, value in options.items():
                 print("{}: {}".format(key, value))
-            return
+            return None
 
     if all(x is None for x in {enable_autocp, enable_raw, default_syntax, default_expires}):
         click.echo("Try 'dpaster config --help' for help")
-        return
+        return None
 
     with open(CONF_PATH, "r") as conf_file:
         options = json.load(conf_file)
@@ -150,7 +167,7 @@ def config(show, enable_autocp, enable_raw, default_syntax, default_expires):
         json.dump(options, conf_file)
 
 
-def get_syntax(filename, content):
+def get_syntax(filename: str, content: str) -> str:
     if filename != "<stdin>":
         try:
             syntax = pygments.lexers.guess_lexer_for_filename(filename, content)
